@@ -33,11 +33,11 @@
 void
 ListWindow::Paint(const ListRenderer &renderer) const noexcept
 {
-	bool show_cursor = HasCursor() &&
+	bool cursor_visible = IsCursorVisible() &&
 		(!options.hardware_cursor || HasRangeSelection());
 	ListWindowRange range;
 
-	if (show_cursor)
+	if (cursor_visible)
 		range = GetRange();
 
 	for (unsigned i = 0; i < GetHeight(); i++) {
@@ -49,7 +49,7 @@ ListWindow::Paint(const ListRenderer &renderer) const noexcept
 			break;
 		}
 
-		bool is_selected = show_cursor &&
+		bool is_selected = cursor_visible &&
 			range.Contains(j);
 
 		renderer.PaintListItem(w, j, i, width, is_selected);
@@ -87,6 +87,7 @@ ListWindow::Find(const ListText &text,
 
 			if (m(label)) {
 				MoveCursor(i);
+				HighlightCursor();
 				return true;
 			}
 			if (wrap && i == GetCursorIndex())
@@ -133,6 +134,7 @@ ListWindow::ReverseFind(const ListText &text,
 
 			if (m(label)) {
 				MoveCursor(i);
+				HighlightCursor();
 				return true;
 			}
 			if (wrap && i == (int)GetCursorIndex())
@@ -168,6 +170,7 @@ ListWindow::Jump(const ListText &text, const char *str) noexcept
 
 		if (m(label)) {
 			MoveCursor(i);
+			HighlightCursor();
 			return true;
 		}
 	}
