@@ -1,6 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
-   (c) 2004-2020 The Music Player Daemon Project
-   Project homepage: http://musicpd.org
+   Copyright 2004-2021 The Music Player Daemon Project
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
@@ -28,7 +27,7 @@
 
 #include "aconnect.hxx"
 #include "net/AsyncResolveConnect.hxx"
-#include "net/AsyncHandler.hxx"
+#include "net/SocketError.hxx"
 #include "net/UniqueSocketDescriptor.hxx"
 #include "system/Error.hxx"
 #include "event/SocketEvent.hxx"
@@ -36,11 +35,10 @@
 #include <mpd/client.h>
 #include <mpd/async.h>
 
-#include <cerrno>
 #include <cstdio>
 #include <cstring>
 
-struct AsyncMpdConnect final : AsyncConnectHandler {
+struct AsyncMpdConnect final : ConnectSocketHandler {
 	AsyncMpdConnectHandler &handler;
 
 	AsyncResolveConnect rconnect;
@@ -60,8 +58,8 @@ struct AsyncMpdConnect final : AsyncConnectHandler {
 	void OnReceive(unsigned events) noexcept;
 
 	/* virtual methods from AsyncConnectHandler */
-	void OnConnect(UniqueSocketDescriptor fd) noexcept override;
-	void OnConnectError(std::exception_ptr e) noexcept override;
+	void OnSocketConnectSuccess(UniqueSocketDescriptor fd) noexcept override;
+	void OnSocketConnectError(std::exception_ptr ep) noexcept override;
 };
 
 void
@@ -71,7 +69,7 @@ try {
 	ssize_t nbytes = socket.GetSocket().Read(buffer, sizeof(buffer));
 
 	if (nbytes < 0)
-		throw MakeErrno("Failed to receive from MPD");
+		throw MakeSocketError("Failed to receive from MPD");
 
 	buffer[nbytes] = 0;
 
@@ -93,14 +91,14 @@ try {
 }
 
 void
-AsyncMpdConnect::OnConnect(UniqueSocketDescriptor fd) noexcept
+AsyncMpdConnect::OnSocketConnectSuccess(UniqueSocketDescriptor fd) noexcept
 {
 	socket.Open(fd.Release());
 	socket.ScheduleRead();
 }
 
 void
-AsyncMpdConnect::OnConnectError(std::exception_ptr e) noexcept
+AsyncMpdConnect::OnSocketConnectError(std::exception_ptr e) noexcept
 {
 	handler.OnAsyncMpdConnectError(std::move(e));
 	delete this;
