@@ -1,6 +1,5 @@
 /* ncmpc (Ncurses MPD Client)
- * (c) 2004-2020 The Music Player Daemon Project
- * Project homepage: http://musicpd.org
+ * Copyright 2004-2021 The Music Player Daemon Project
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,7 +32,7 @@ ScreenManager::PaintTopWindow() noexcept
 }
 
 void
-ScreenManager::Paint(bool main_dirty) noexcept
+ScreenManager::Paint() noexcept
 {
 	/* update title/header window */
 	PaintTopWindow();
@@ -47,7 +46,7 @@ ScreenManager::Paint(bool main_dirty) noexcept
 
 	/* paint the main window */
 
-	if (main_dirty) {
+	if (current_page->second->IsDirty()) {
 		current_page->second->Paint();
 		current_page->second->SetDirty(false);
 	}
